.. _forms_concept:

===============
     Forms
===============

.. contents::
   :depth: 2
   :local:
   :backlinks: none




What is a form?
---------------

A form in the Pseudopeople framework is analogous to a dataset representing
a census survey or tax document.  The types of forms that are compatible with
the Pseudopeople framework include:

.. list-table:: **Types of Forms**
   :header-rows: 1
   :widths: 20

   * - Name
   * - | Decennial census
   * - | American communities survey
   * - | Current population survey
   * - | Women, infrants, and children survey
   * - | Social security
   * - | Tax W2 and 1099 forms
   * - | Tax 1040 form
